"""
Setup script for Lexitheras
"""

from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="lexitheras",
    version="1.0.1",
    author="Conor Reid",
    author_email="",  # Add your email if you want
    description="Convert Perseus Greek vocabulary lists into Anki flashcard decks",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/conorreid/lexitheras",
    packages=find_packages(where="src"),
    package_dir={"": "src"},
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Education",
        "Topic :: Education",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    python_requires=">=3.6",
    entry_points={
        "console_scripts": [
            "lexitheras=lexitheras.cli:main",
        ],
    },
)